Module: Google::Cloud::ManagedIdentities
- Defined in:
- lib/google/cloud/managed_identities.rb,
lib/google/cloud/managed_identities/version.rb
Constant Summary collapse
- VERSION =
"1.6.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.managed_identities| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-managed_identities library.
-
.managed_identities_service(version: :v1, &block) ⇒ ::Object
Create a new client object for ManagedIdentitiesService.
-
.managed_identities_service_available?(version: :v1) ⇒ boolean
Determines whether the ManagedIdentitiesService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.managed_identities| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-managed_identities library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
169 170 171 172 173 |
# File 'lib/google/cloud/managed_identities.rb', line 169 def self.configure yield ::Google::Cloud.configure.managed_identities if block_given? ::Google::Cloud.configure.managed_identities end |
.managed_identities_service(version: :v1, &block) ⇒ ::Object
Create a new client object for ManagedIdentitiesService.
By default, this returns an instance of
Google::Cloud::ManagedIdentities::V1::ManagedIdentitiesService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ManagedIdentitiesService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the ManagedIdentitiesService service. You can determine whether the method will succeed by calling managed_identities_service_available?.
About ManagedIdentitiesService
API Overview
The managedidentites.googleapis.com service implements the Google Cloud
Managed Identites API for identity services
(e.g. Microsoft Active Directory).
The Managed Identities service provides methods to manage (create/read/update/delete) domains, reset managed identities admin password, add/remove domain controllers in GCP regions and add/remove VPC peering.
Data Model
The Managed Identities service exposes the following resources:
Locations as global, named as follows:
projects/{project_id}/locations/global.Domains, named as follows:
/projects/{project_id}/locations/global/domain/{domain_name}.
The {domain_name} refers to fully qualified domain name in the customer
project e.g. mydomain.myorganization.com, with the following restrictions:
- Must contain only lowercase letters, numbers, periods and hyphens.
- Must start with a letter.
- Must contain between 2-64 characters.
- Must end with a number or a letter.
- Must not start with period.
- First segement length (mydomain form example above) shouldn't exceed 15 chars.
- The last segment cannot be fully numeric.
- Must be unique within the customer project.
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/google/cloud/managed_identities.rb', line 103 def self.managed_identities_service version: :v1, &block require "google/cloud/managed_identities/#{version.to_s.downcase}" package_name = Google::Cloud::ManagedIdentities .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::ManagedIdentities.const_get(package_name).const_get(:ManagedIdentitiesService) service_module.const_get(:Client).new(&block) end |
.managed_identities_service_available?(version: :v1) ⇒ boolean
Determines whether the ManagedIdentitiesService service is supported by the current client. If true, you can retrieve a client object by calling managed_identities_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ManagedIdentitiesService service, or if the versioned client gem needs an update to support the ManagedIdentitiesService service.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/cloud/managed_identities.rb', line 125 def self.managed_identities_service_available? version: :v1 require "google/cloud/managed_identities/#{version.to_s.downcase}" package_name = Google::Cloud::ManagedIdentities .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::ManagedIdentities.const_get package_name return false unless service_module.const_defined? :ManagedIdentitiesService service_module = service_module.const_get :ManagedIdentitiesService service_module.const_defined? :Client rescue ::LoadError false end |